# remirepo spec file for php-pecl-memprof
# With SCL compatibility, from Fedora:
#
# Fedora spec file for php-pecl-memprof
#
# SPDX-FileCopyrightText:  Copyright 2013-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%if %{__isa_bits} < 64
# some tests fail on 32-bit
%bcond_with    tests
%else
%bcond_without tests
%endif

%{?scl:%scl_package php-pecl-memprof}

# ZTS build is broken
# https://github.com/arnaud-lb/php-memory-profiler/pull/7
%global with_zts   0
%global pecl_name  memprof
%global pie_vend   arnaud-lb
%global pie_proj   memprof
%global ini_name   40-%{pecl_name}.ini
%global sources    %{pecl_name}-%{version}
%global _configure ../%{sources}/configure

Summary:        Memory usage profiler
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        3.1.0
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# see https://github.com/arnaud-lb/php-memory-profiler/issues/93
License:        MIT
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.1
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  Judy-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}                 = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})           = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}   = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}


%description
Memprof is a fast and accurate memory profiler that can be used
to find the cause of memory leaks in PHP applications.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_MEMPROF_VERSION/{s/.* "//;s/".*$//;p}' php_memprof.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;memprof.output_dir = '/tmp'
;memprof.output_format = 'callgrind'
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
# Unusable
cd %{sources}
rm tests/autodump-xdebug.phpt

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
grep "HAVE_MALLOC_HOOKS 1" ../NTS/config.h && export MEMPROF_EXPECT_NATIVE_TRACKING=1

: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{_bindir}/php -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Tue Feb 25 2025 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0
- re-license spec file to CECILL-2.1

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 3.0.2-3
- rebuild for PHP 8.3.0RC1

* Thu Jul 13 2023 Remi Collet <remi@remirepo.net> - 3.0.2-2
- build out of sources tree
- open https://github.com/arnaud-lb/php-memory-profiler/issues/93
  license clarification

* Fri Jan  7 2022 Remi Collet <remi@remirepo.net> - 3.0.2-1
- update to 3.0.2
- drop patches merged upstream

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 3.0.1-2
- rebuild for 8.1.0RC1

* Fri Jul  2 2021 Remi Collet <remi@remirepo.net> - 3.0.1-1
- update to 3.0.1
- add patch for PHP 8.1 from
  https://github.com/arnaud-lb/php-memory-profiler/pull/54

* Tue Mar 30 2021 Remi Collet <remi@remirepo.net> - 3.0.0-1
- update to 3.0.0

* Thu Nov 19 2020 Remi Collet <remi@remirepo.net> - 2.1.2-1
- update to 2.1.2 (no change)
- run upstream test suite during the build

* Wed Nov 18 2020 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1
- open https://github.com/arnaud-lb/php-memory-profiler/pull/43
  raise PHP minimal version to 7.1 and add tests to archive

* Sun Jul  5 2020 Remi Collet <remi@remirepo.net> - 2.1.0-1
- update to 2.1.0

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 2.0.0-6
- rebuild for 7.4.0RC1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 2.0.0-5
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 2.0.0-4
- rebuild for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.0-3
- rebuild for PHP 7.2.0beta1 new API

* Sun Feb  5 2017 Remi Collet <remi@fedoraproject.org> - 2.0.0-2
- use package2.xml for correct registration

* Sat Jan 28 2017 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- update to 2.0.0 for PHP 7+
- open https://github.com/arnaud-lb/php-memory-profiler/pull/13
  fix version and use normalized macro name
- open https://github.com/arnaud-lb/php-memory-profiler/issues/14
  usage clarification

* Wed Mar  9 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-6
- adapt for F24

* Tue Jun 23 2015 Remi Collet <rcollet@redhat.com> - 1.0.0-6
- allow build against rh-php56 (as more-php56)
- drop runtime dependency on pear, new scriptlets

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 1.0.0-5.1
- Fedora 21 SCL mass rebuild

* Mon Aug 25 2014 Remi Collet <rcollet@redhat.com> - 1.0.0-5
- improve SCL build

* Thu Apr 10 2014 Remi Collet <remi@fedoraproject.org> - 1.0.0-4
- add numerical prefix to extension configuration file

* Tue Oct 22 2013 Remi Collet <remi@fedoraproject.org> - 1.0.0-3
- install doc in pecl doc_dir

* Fri Oct 11 2013 Remi Collet <rcollet@redhat.com> - 1.0.0-2
- allow SCL build

* Sun Oct  6 2013 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- initial package, version 1.0.0 (stable)
- open https://github.com/arnaud-lb/php-memory-profiler/pull/6
- open https://github.com/arnaud-lb/php-memory-profiler/pull/7
